@@ -11,7 +11,18 @@ from mezzanine import settings as blog_settings
 
 
 class HtmlField(models.TextField):
-    pass
+    """
+    TextField that stores HTML.
+    """
+
+    def formfield(self, **kwargs):
+        """
+        Apply the class to the widget that will render the field as a 
+        TincyMCE Editor.
+        """
+        formfield = super(HtmlField, self).formfield(**kwargs)
+        formfield.widget.attrs["class"] = "mceEditor"
+        return formfield
     
 class Displayable(models.Model):
     """
